Licencia Ğ1 - v0.2.9
====================

:fecha: 2017-04-04 12:59
:modificada: 2019-04-16 22:30

**Licenza d'uso della moneta e presa di responsabilità**

Ogni operazione di certificazione di un nuovo membro della Ğ1 deve essere prima accompagnata dalla trasmissione di questa licenza d'uso della moneta libera Ğ1, la quale il certificatore deve assicurarsi sia stata studiata, compresa e accettata dalla persona. Ogni evento riguardante la Ğ1 deve essere accompagnato dalla trasmissione di questa licenza, che può essere letta ad alta voce e trasmessa in ogni forma.

​​​​​​​Rete di fiducia Ğ1 (RdF - Rete di Fiducia Ğ1)
---------------------------------------------

**Attenzione:** certificare non significa solo assicurarsi di aver incontrato fisicamente la persona, bensì è assicurare alla comunità Ğ1 che si conosce la persona  certificata abbastanza bene da poterla contattare facilmente, e di essere in grado di individuare un conto duplicato fatto da una persona che si è certificata, o altri tipi di problemi (morte...), facendo un controllo incrociato che rivelerà il problema se necessario.

**Consigli fortemente raccomandati**

Conoscere bene una persona implica che si è in grado di contattarla con diversi mezzi (fisici, elettronici, altro…), ma anche che si conosscono diverse persone che la conoscono altrettanto bene e che quindi sono anche loro in grado di contattarla allo stesso modo; in particolare, se non si conosce bene qualcuno tra coloro che l’hanno già certificata, è una chiara indicazione che non si conosce in modo sufficiente questa persona, e una certificazione di questo tipo fa scattare un allarme in  tutta la comunità Ğ1. In caso di conoscenza insufficiente, è importante NON certificare.

Non certificare mai da soli, ma insieme almeno ad un altro membro della RdF Ğ1, per evitare errori nel processo. In caso di errore, si devono avvisare immediatamente altri membri della RdF Ğ1.

Prima di ogni certificazione, bisogna assicurarsi di controllare se il conto della persona candidata (sia come nuovo richiedente sia come già membro) non abbia già ricevuto una o più certificazioni. Se necessario, chiedete informazioni per contattare coloro che lo hanno già certificato in precedenza in modo da verificare insieme di conoscere bene la persona in questione, così come la sua chiave pubblica corrispondente.

Verificate che il candidato membro abbia un buon controllo nella gestione del suo conto: un buon modo per verificarlo è quello di trasferire alcune Ğ1 sul conto di destinazione, e di rimando chiedere di effettuare un piccolo rimborso sul proprio conto. Questo assicura che il candidato abbia una buona padronanza della sua chiave privata.

Controllate che i vostri contatti abbiano studiato e compreso questa Licenza aggiornata della Ğ1.

Se ci si accerta che un certificatore effettivo o potenziale del conto del candidato non conosce il candidato in questione, é necessario avvertire immediatamente chiunque abbia esperienza in materia, tra i vostri contatti nella RdF Ğ1, in modo che la RdF Ğ1 possa verificare il processo di convalida.

**Nel momento in cui, in qualità di membri della RdF G1, ci si accinge a certificare un nuovo conto, bisogna essere certi:**

1°) di conoscere sufficientemente bene (non solamente di vista) la persona che dichiara di saper gestire questa chiave pubblica (nuovo conto). Leggere i consigli fortemente raccomandati qui sopra per essere sicuri di "conoscerla bene".

2°) di verificare personalmente con il candidato che sia questa la sua chiave pubblica che si sta per certificare (leggere i suggerimenti sopra).

3°) che la persona interessata abbia generato il suo documento Duniter di revoca del conto che gli permetterà, se necessario, di disattivare il suo status di membro (in caso di furto del conto, cambio di identità, conto creato in modo errato, dimenticanza dellechiavi di accesso, ecc.).

4a°) di aver incontrato il candidato di persona per assicurarti che sia la persona fisica che conosci bene e che ha questa chiave pubblica.

4b°) Oppure di aver verificato a distanza la corrispondenza tra la chiave pubblica e la persona (che hai già incontrato fisicamente), utilizzando più di un mezzo di comunicazione​​​​​​​, ad esempio posta ordinaria + social network + forum + email + video conferenza + telefono (riconoscimento vocale). Questo perché se si può violare un account di posta elettronica o di un forum, è molto più difficile immaginare di violare quattro mezzi di comunicazione distinti, e imitare l'aspetto (video) e persino la voce della persona fisica .

Tuttavia, 4a) è preferibile a 4b), mentre i punti 1) 2) e 3) sono prioritari ed indispensabili.

**Regole della RdF in breve:**

Ogni membro ha una riserva di 100 certificazioni possibili, che possono essere rilasciate solo al ritmo di 1 certificazione ogni 5 giorni.

Una certificazione per un nuovo membro è valida per 2 mesi ed è ratificata solo se la persona certificata ha almeno altre 4 certificazioni alla fine di questi 2 mesi, altrimenti il processo di accreditamento deve essere riavviato.

Per diventare un nuovo membro della RdF Ğ1, è necessario ottenere 5 certificazioni ed essere ad una distanza massima di 5 passi rispetto all'80% del numero totale dei membri referenti della RdF.

Si definisce membro referente della RdF Ğ1 colui che abbia ricevuto e anche rilasciato almeno Y[N] certificazioni dove N è il numero totale di membri nella RdF e Y[N] = tetto N^(1/5). Esempi:

* Per 1024 < N ≤ 3125 si ottiene Y[N] = 5
* Per 7776 < N ≤ 16807 si ottiene Y[N] = 7
* per 59049 < N ≤ 100.000 si ottiene Y[N] = 10

Una volta diventato membro della RdF Ğ1, le sue certificazioni saranno valide per 2 anni.

Per rimanere membro, è necessario rinnovare regolarmente l'accordo, tramite la chiave privata (ogni 12 mesi) e assicurarsi di avere sempre almeno 5 certificazioni valide dopo i 2 anni.

Moneta Ğ1
---------

La nuova moneta Ğ1 è generata attraverso un Dividendo Universale (DU) per ogni essere umano membro della Rete di Fiducia Ğ1, come segue:

* 1 DU per persona al giorno.

La quantità in Ğ1 del DU è la stessa ogni giorno fino all'equinozio successivo (ogni 6 mesi), quando il DU sarà rivalutato secondo la formula (1 giorno = 86.400 secondi):

* DU quotidiano (prossimo equinozio) = DU quotidiano (equinozio) + c² (M/N)(equinozio) / (15.778.800 secondi).
Dove i parametri sono:

* c = 4,88% / equinozio

* DU(0) = 10.00 Ğ1

E le variabili sono:

* M La massa monetaria all'equinozio
* N Il numero di membri nel giorno dell'equinozio

Software Ğ1 e licenza Ğ1
------------------------

I software Ğ1 che permettono agli utenti di gestire l'uso della moneta Ğ1 devono trasmettere la presente licenza insieme al software, così come tutti i parametri tecnici della moneta Ğ1 e della RdF Ğ1, che sono registrati nel blocco 0 di Duniter, la blockchain Ğ1.

Il software che non rispetta questi obblighi di licenza non è compatibile con la Ğ1.

Per maggiori dettagli tecnici, è possibile consultare direttamente il codice di Duniter, che è un software libero, così come i dati della blockchain Ğ1, recuperandoli attraverso un'istanza di Duniter o un nodo Ğ1.

Maggiori informazioni sul sito web del team Duniter, https://www.duniter.org
